@@ -192,6 +192,12 @@ function addArc(center, radius, startAngle, endAngle, reversed) {
     if (isArray(center)) {
         center = new RVector(center);
     }
+
+    if (!isVector(center)) {
+        qWarning("invalid center");
+        throw("invalid center");
+    }
+
     return addShape(new RArc(center, radius, deg2rad(startAngle), deg2rad(endAngle), reversed));
 }
 
@@ -232,7 +238,7 @@ function addCircle(center, radius) {
  * relative: True if this vector's coordinates are relative to the previous coordinates,
  * defaults to false.
  *
- * \param closed True for an implicitely closed polyline. Default is false.
+ * \param closed True for an implicitly closed polyline. Default is false.
  * \param relative True to treat all coordinates as relative.
  * The first coordinate is always absolute. Default is false.
  *
@@ -392,7 +398,7 @@ function addSimpleText(text, position, height, angle, font, vAlign, hAlign, bold
               position,
               position,
               height,
-              100.0,
+              0.0,
               vAlign,
               hAlign,
               RS.LeftToRight,
